# Contributors

We are grateful for contributions and would like to acknowledge all people who have helped improving the code and the documentation. What follows is an incomplete list, see [contributors](https://github.com/odlgroup/odl/graphs/contributors) for a complete list and feel free to add yourself!

## Contributors in alphabetic order

* [Jonas Adler](https://github.com/adler-j). Created much of the `Set`, `LinearSpace` and `Operator` structure including utilities. Has also contributed to most other submodules.
* [Sebastian Banert](https://github.com/sbanert). Contributions to `odl.solvers`.
* [Chong Chen](https://github.com/chongchenmath). Started work on the `odl.deform` package.
* [Matthias J. Ehrhardt](https://github.com/mehrhardt). Several contributions to `odl.solvers`, in addition to general bug fixes and improvements.
* [Barbara Gris](https://github.com/bgris). Added `examples/solvers/find_optimal_parameters`.
* [Johan Karlsson](https://github.com/hilding79). Contributions to `odl.solvers`.
* [Holger Kohr](https://github.com/kohr-h). Was part of the design of ODL and created several of the submodules, including `odl.discr`, `odl.trafos` and `odl.tomo`. Has contributed to most modules.
* [Gregory R. Lee](https://github.com/grlee77). Bugfixes.
* [Julian Moosmann](https://github.com/moosmann). Significant work on the initial `odl.tomo` module.
* [Kati Niinimäki](https://github.com/niinimaki). Implemented the `WaveletTransform`.
* [Willem Jan Palenstijn](https://github.com/wjp). Added adjoint of `RayTransform`.
* [Axel Ringh](https://github.com/aringh). Created much of the `odl.solvers` module, in particular oversaw the addition of `Functional`.
* [Justus Sagemüller] (https://github.com/leftaroundabout). Package developer since 2023. Made ODL mutli-backend and array-API compatible.
* [Emilien Valat] (https://github.com/Emvlt). Package developer since 2024. Made ODL mutli-backend and array-API compatible.
* [Olivier Verdier](https://github.com/olivierverdier). Typos.
* [Gustav Zickert](https://github.com/zickert). Started the `odl.contrib.fom` package.
* [Ozan Öktem](https://github.com/ozanoktem). Father of the project. Proposed the idea and made sure we had money to get it done!
